@@ -18,16 +18,12 @@ class QueueHandler(logging.Handler):
 
 
 # Adapted from https://beenje.github.io/blog/posts/logging-to-a-tkinter-scrolledtext-widget/
-class ConsoleWindow(tk.Toplevel):
+class ConsoleWindow(tk.Frame):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.wm_title("Modlunky2 Console")
-        self.geometry("1024x600")
-        # self.resizable(False, False)
-        self.protocol("WM_DELETE_WINDOW", self.close)
 
         # Create a ScrolledText wdiget
-        self.scrolled_text = ScrolledText(self, state="disabled")
+        self.scrolled_text = ScrolledText(self, height=7, state="disabled")
         self.scrolled_text.pack(expand=True, fill="both")
         self.scrolled_text.configure(font="TkFixedFont")
         self.scrolled_text.tag_config("INFO", foreground="green")
@@ -68,6 +64,29 @@ class ConsoleWindow(tk.Toplevel):
         pass
 
 
+class ToolTip:
+    def __init__(self, widget, text):
+        self.widget = widget
+        self.text = text
+
+        self.widget.bind('<Enter>', self.on_enter)
+        self.widget.bind('<Leave>', self.on_leave)
+
+        self.tooltip = None
+        self.label = None
+
+    def on_enter(self, event):
+        self.tooltip = tk.Toplevel()
+        self.tooltip.overrideredirect(True)
+        self.tooltip.geometry(f'+{event.x_root+15}+{event.y_root+10}')
+
+        self.label = tk.Label(self.tooltip,text=self.text)
+        self.label.pack()
+
+    def on_leave(self, _event):
+        self.tooltip.destroy()
+
+
 class Tab(ttk.Frame):
     """ Base class that all tabs should inherit from."""
 
